// Importing necessary D3 modules
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  area,
  max
} from 'd3';
// Selecting the SVG element
const svg = select('svg');

// Getting the width and height of the SVG
const width = +svg.attr('width');
const height = +svg.attr('height');
// Defining the function to render the line plot
const render = data => {
// Defining the x-value accessor function and label
const xValue = d => d.Year;
const xAxisLabel = 'Year';

// Defining the y-value accessor function and label
const yValue = d => d.Global_Sales;
const yAxisLabel = 'Global Sales in Millions';
// Defining the margin and inner dimensions of the plot
  const margin = { top: 7, right: 20, bottom: 118, left: 110 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  const circleRadius = 7;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0]);
// Creating a group element for the plot
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  //create x-axis
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
  	.tickFormat(d3.format("d"))
    .tickPadding(10);
  //create y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  	.ticks(8, "s");
  	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  //y-axis label
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //x-axis label
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing the line plot 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
//area generator  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)));
  
 		 g.append('path')
  		.attr('class', 'line_path')
  		.attr('d', lineGenerator(data))
  
  	g.append('path')
  		.attr('class', 'area-chart')
  		.attr('d', areaGenerator(data));
};

// Loading CSV data
csv('https://gist.githubusercontent.com/VemulaDowtyasriprasanth/60e7c314ee2086afd925128a5270e76d/raw/dcb2f9cda54cdb613dc546ff5e1fc560d1216069/GameSalesSorted.csv')
  .then(data => {
    data.forEach(d => {
    	d.Global_Sales = +d.Global_Sales;
      d.Year = +d.Year;
    });
//rendering plot
   const slicedData = data.slice(0, 14000); // slice the first 100 data points
    
    render(slicedData);
  });